\name{cov.spatial}

\alias{cov.spatial}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Computes covariances for several types of correlation functions}

\description{
  Computes the covariances for pairs of points, given their separation distance.
  Can be see as a change of metric, from the \emph{euclidian distances} to
  \emph{covariances}. This is an auxiliary function called by several
  functions in the \code{geoR} library.
}

\usage{
cov.spatial(obj, cov.model=c("exponential", "matern", "gaussian",
            "spherical", "circular", "cubic", "wave",
            "powered.exponential", "cauchy", 
            "gneiting", "gneiting.matern", "pure.nugget"),
            cov.pars=stop("no cov.pars argument provived"), kappa)
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{obj}{an object (vector or matrix) with distances.}
  \item{cov.model}{a string indicating the type of the correlation
    function. See the DETAILS for options and expressions of the correlation functions.}
  \item{cov.pars}{a vector with 2 elements or a \eqn{ns x 2} matrix with
    the covariance parameters. The fist element (if a vector) or first column (if a matrix) is the variance parameter \eqn{\sigma^2}{sigma^2}. The
    second element or column is the correlation function parameter
    \eqn{\phi}{phi}. If a matrix is provided, each row corresponds to
    the parameters of one \emph{structure}. Models with several structures
    are sometimes called \emph{nested models} in the geostatistical literature.}
  \item{kappa}{additional parameter needed for some of the correlation
    functions: (\code{"matern", "powered.exponential", "gneiting"} and
    \code{"gneiting.matern"}).}
}


\details{
  EXPRESSIONS OF THE CORRELATION FUNCTIONS HERE
}

\value{
  ~Describe the value returned
  If it is a LIST, use
  \item{comp1 }{Description of `comp1'}
  \item{comp2 }{Description of `comp2'}
  ...
}

\references{
  Further information about \code{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

\note{ ~~further notes~~ }


\seealso{\code{\link{varcov.spatial}}, \code{\link{likfit}}, \code{\link{krige.bayes}}, \code{\link{krige.conv}}, \code{\link{grf}}. }

\examples{
# Some variogram models with the same pratical range:
xval <- seq(0,1,l=100)
vexp <- cov.spatial(xval, cov.pars=c(1, .2))
vsph <- cov.spatial(xval, cov.pars=c(1, .60), cov.model="sph")
vgau <- cov.spatial(xval, cov.pars=c(1, .60/sqrt(3)), cov.model="gau")
plot(0:1, 0:1, type="n")
lines(xval, (1-vexp))
lines(xval, (1-vsph), lty=2)
lines(xval, (1-vgau), lwd=2)

}


\keyword{spatial}%-- one or more ...





